@@ -824,4 +824,4 @@ def no_coin(loot: Loot) -> Loot:
 
 if __name__ == '__main__':
     print()
-    print(RankOneLoot())
+    print(RankFourHoardLoot())
